@@ -7,6 +7,9 @@
 #' @param burnin Number of initial time points to discard (to simulate stationary data)
 #' @param dtmean Positive numeric. Average time interval (delta T) to use.
 #' @param logdtsd Numeric. Standard deviation for variability of the time interval.
+#' @param dtmat Either NA, or numeric matrix of n.subjects rows and Tpoints-1 columns, 
+#' containing positive numeric values for all time intervals between measurements. 
+#' If not NA, dtmean and logdtsd are ignored.
 #' @param wide Logical. Output in wide format?
 #' @details TRAITVAR and MANIFESTRAITVAR are treated as Cholesky factor covariances 
 #' of CINT and MANIFESTMEANS, respectively. 
@@ -30,7 +33,7 @@
 #' data<-ctGenerate(generatingModel,n.subjects=15,burnin=10)
 #' @export
 
-ctGenerate<-function(ctmodelobj,n.subjects=100,burnin=0,dtmean=1,logdtsd=0,
+ctGenerate<-function(ctmodelobj,n.subjects=100,burnin=0,dtmean=1,logdtsd=0,dtmat=NA,
   wide=TRUE){
   
   
@@ -86,7 +89,6 @@ ctGenerate<-function(ctmodelobj,n.subjects=100,burnin=0,dtmean=1,logdtsd=0,
   fullTpoints<-burnin+Tpoints
   
   # if(n.TDpred > 0) { #add burnin to TDPREDMEANS
-  #   browser()
   #   TDPREDMEANS <- matrix(rbind(matrix(0,nrow=1+(burnin),ncol=n.TDpred)[-1,,drop=FALSE], #additional row added then removed in case no burnin
   #   matrix(TDPREDMEANS,ncol=n.TDpred)),ncol=1) #ugly transform to avoid burnin offset with multiple tdpreds 
   # }
@@ -95,9 +97,10 @@ ctGenerate<-function(ctmodelobj,n.subjects=100,burnin=0,dtmean=1,logdtsd=0,
   
   for(si in 1:n.subjects){
     
-    dt<- exp(rnorm(fullTpoints,log(dtmean),logdtsd))
+    if(is.na(dtmat[1])) dtvec<- exp(rnorm(fullTpoints,log(dtmean),logdtsd))
+    if(!is.na(dtmat[1])) dtvec <- dtmat[si,]
     time=rep(0,fullTpoints)
-    for(t in 2:fullTpoints) time[t] = round(time[t-1] + dt[t],3)
+    for(t in 2:fullTpoints) time[t] = round(time[t-1] + dtvec[t-1],3)
     
     
     if(n.TDpred > 0) {
@@ -130,7 +133,7 @@ ctGenerate<-function(ctmodelobj,n.subjects=100,burnin=0,dtmean=1,logdtsd=0,
     
     colnames(sdat) <- colnames(datalong)
     
-    sdat[,manifestNames] <- ctKalman(kpars=skpars,datalong=sdat,manifestNames=manifestNames,TDpredNames=TDpredNames,
+    sdat[,manifestNames] <- Kalman(kpars=skpars,datalong=sdat,manifestNames=manifestNames,TDpredNames=TDpredNames,
       latentNames=latentNames,
       imputeMissings=TRUE)$y
     
