@@ -26,9 +26,13 @@ stanWplot <- function(iter=2000,chains=4,...){
 tmpdir=tempdir()
 tmpdir=gsub('\\','/',tmpdir,fixed=TRUE)
 
+windows= Sys.info()[1]=='Windows'
 
 stanplot<-function(chains,seed){
   wd<-  paste0("setwd('",tmpdir,"')")
+  
+  if(1==99) shiny::runApp(appDir = getwd(), {})
+  
   writeLines(text=paste0(wd,'
     seed<-',seed,';
     chains<-',chains,';
@@ -37,11 +41,11 @@ stanplot<-function(chains,seed){
     notyet<-TRUE
     while(notyet==TRUE){
     Sys.sleep(1);
-    samps<-try(read.csv(file=paste0(seed,"samples_1.csv"),comment.char="#"))
+    samps<-try(read.csv(file=paste0(seed,"samples_1.csv"),comment.char="#"),silent=TRUE)
     if(class(samps) != "try-error") notyet<-FALSE
     }
     varnames<-colnames(samps);
-    require(shiny); 
+    # require(shiny); 
     shiny::runApp(appDir=list(server=function(input, output,session) {
     
     output$chainPlot <- renderPlot({
@@ -52,7 +56,7 @@ stanplot<-function(chains,seed){
     begin<-input$begin
     samps<-list()
     for(chaini in 1:chains) {
-    samps[[chaini]]<-try(read.csv(file=paste0(seed,"samples_",chaini,".csv"),comment.char="#",colClasses = colimport))
+    samps[[chaini]]<-try(read.csv(file=paste0(seed,"samples_",chaini,".csv"),comment.char="#",colClasses = colimport),silent=TRUE)
     if(class(samps[[chaini]])=="try-error") samps[[chaini]]=samps[[1]][1,,drop=FALSE]
 }
     
@@ -92,19 +96,20 @@ stanplot<-function(chains,seed){
     ))),
     launch.browser=TRUE)
     quit(save="no")'),con=paste0(tmpdir,"/stanplottemp.R"))
-  system(paste0("Rscript --slave --no-restore -e source(\'",tmpdir,"/stanplottemp.R\')"),wait=FALSE)
+  
+  if(windows) system(paste0("Rscript --slave --no-restore -e source(\'",tmpdir,"/stanplottemp.R\')"),wait=FALSE) else
+    system(paste0(R.home(component = "home"),"/Rscript --slave --no-restore -e source\\(\\\'",tmpdir,"\\/stanplottemp.R\\\'\\)"),wait=FALSE)
   
 }
 
 stanseed<-floor(as.numeric(Sys.time()))
 
-  sample_file<-paste0(tmpdir,'/',stanseed,'samples.csv')
+  sample_file<-paste0(tmpdir,'/',stanseed,'samples', ifelse(chains==1,'_1',''),'.csv')
 
   stanplot(chains=chains,seed=stanseed)
   
   out=stan(iter=iter,chains=chains,sample_file=sample_file,...)
 
-
   for(chaini in 1:chains) system(paste0("rm ",tmpdir,'/',stanseed,"samples_",chaini,".csv"))
   system(paste0('rm ',tmpdir,'/stanplottemp.R'))
   return(out)
