@@ -20,9 +20,11 @@ genm=ctModel(Tpoints=Tpoints,
   MANIFESTVAR=matrix(c(1, 0,0,.5), nrow=n.manifest, ncol=n.manifest),
   TRAITVAR=matrix(c(1,.5,0,.8),n.latent,n.latent))
 
-cd=ctGenerate(ctmodelobj=genm, n.subjects=nsubjects, burnin=50, dtmean=.9, 
+cd=ctGenerate(ctmodelobj=genm, n.subjects=nsubjects, burnin=51, dtmean=1, 
   logdtsd=0,simultdpredeffect=TRUE,wide=TRUE)
 
+wide=cd
+
 long=ctWideToLong(datawide = cd,Tpoints = Tpoints,n.manifest = n.manifest)
 long=ctDeintervalise(datalong = long)
 long=long[-seq(3,length(long),3),]
@@ -34,9 +36,11 @@ wide=ctIntervalise(datawide = wide,Tpoints = Tpoints,n.manifest = n.manifest)
 mltrait<-ctModel(Tpoints=Tpoints,n.latent=n.latent,n.manifest=n.manifest,
   LAMBDA=diag(1,n.manifest),
   TRAITVAR='auto')
+
 mmtrait<-ctModel(Tpoints=Tpoints,n.latent=n.latent,n.manifest=n.manifest,
   LAMBDA=diag(1,n.manifest),
   MANIFESTTRAITVAR='auto')
+
 mptrait<-ctModel(Tpoints=Tpoints,n.latent=4,n.manifest=n.manifest,
   LAMBDA=matrix(c(1,0, 0,1, 0,0, 0,0),2,4),
   DRIFT=matrix(c(
@@ -52,16 +56,23 @@ mptrait<-ctModel(Tpoints=Tpoints,n.latent=4,n.manifest=n.manifest,
   T0MEANS=matrix(c('t1','t2',0,0),ncol=1))
 
 fmlstrait=ctFit(datawide = wide,ctmodelobj = mltrait,retryattempts = 5,stationary='T0TRAITEFFECT')
-fmlstrait=ctFit(datawide = wide,ctmodelobj = mltrait,retryattempts = 5,stationary='')
+fmltrait=ctFit(datawide = wide,ctmodelobj = mltrait,retryattempts = 5,stationary='')
+
+dfmlstrait=ctFit(datawide = wide,ctmodelobj = mltrait,retryattempts = 5,discreteTime=TRUE,stationary='T0TRAITEFFECT')
+dfmltrait=ctFit(datawide = wide,ctmodelobj = mltrait,retryattempts = 5,discreteTime=TRUE,stationary='')
+
 fmmtrait=ctFit(datawide = wide,ctmodelobj = mmtrait,retryattempts = 5)
 fmptrait=ctFit(datawide = wide,ctmodelobj = mptrait,retryattempts = 5)
-summary(fmltrait,verbose=TRUE)
+
+summary(fmlstrait,verbose=TRUE)
 summary(fmmtrait)
 summary(fmptrait)
 
 #check traits using different fit approaches
-expect_equal(rep(0,4),c(fmltrait$mxobj$DRIFT$values-fmmtrait$mxobj$DRIFT$values),tolerance=1e-2)
-expect_equal(rep(0,4),c(fmlstrait$mxobj$DRIFT$values-fmptrait$mxobj$DRIFT$values[1:2,1:2]),tolerance=1e-2)
+expect_equal(rep(0,4),c(fmlstrait$mxobj$DRIFT$values-fmmtrait$mxobj$DRIFT$values),tolerance=1e-2)
+expect_equal(rep(0,4),c(fmltrait$mxobj$DRIFT$values-fmptrait$mxobj$DRIFT$values[1:2,1:2]),tolerance=1e-2)
+
+# expect_equal(rep(0,4),c(expm(fmlstrait$mxobj$DRIFT$values)-dfmltrait$mxobj$DRIFT$values),tolerance=1e-2)
 
 #check DRIFT is reasonably estimated
 expect_equal(rep(0,4),c(fmltrait$mxobj$DRIFT$values-DRIFT),tolerance=.1)
